# Generated by Django 2.1 on 2019-02-08 14:16

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cookie_consent", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="LogItem",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "action",
                    models.IntegerField(
                        choices=[(-1, "Declined"), (1, "Accepted")],
                        verbose_name="Action",
                    ),
                ),
                ("version", models.CharField(max_length=32, verbose_name="Version")),
                (
                    "created",
                    models.DateTimeField(auto_now_add=True, verbose_name="Created"),
                ),
                (
                    "cookiegroup",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cookie_consent.CookieGroup",
                        verbose_name="Cookie Group",
                    ),
                ),
            ],
            options={
                "verbose_name": "Log item",
                "verbose_name_plural": "Log items",
                "ordering": ["-created"],
            },
        ),
    ]
